@@ -1,10 +1,13 @@
 from typing import AsyncGenerator
 
+from fastapi import Depends
+from fastapi_users_db_sqlalchemy import SQLAlchemyUserDatabase
 from sqlalchemy.ext.asyncio import AsyncSession, create_async_engine
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker
 
 from defi_common import dbconfig
+from defi_common.database.models import User
 
 DATABASE_URL = dbconfig.db_config.db_url
 
@@ -23,3 +26,7 @@ async def init_models() -> None:
 async def get_session() -> AsyncGenerator:  # type: ignore
     async with async_session() as session:
         yield session
+
+
+async def get_user_db(session: AsyncSession = Depends(get_session)) -> AsyncGenerator: #type: ignore
+    yield SQLAlchemyUserDatabase(session, User)
